Affine Spaces
==========================

.. contents::
    :depth: 2
    :local:

.. currentmodule:: cr.nimble.affine


Homogeneous Coordinate System
------------------------------------

.. autosummary::
    :toctree: _autosummary

    homogenize
    homogenize_vec
    homogenize_cols    
